@@ -18,6 +18,7 @@
 """Processes DAGs."""
 from __future__ import annotations
 
+import collections
 import enum
 import importlib
 import inspect
@@ -44,6 +45,7 @@ import airflow.models
 from airflow.callbacks.callback_requests import CallbackRequest, SlaCallbackRequest
 from airflow.configuration import conf
 from airflow.dag_processing.processor import DagFileProcessorProcess
+from airflow.jobs.base_job import BaseJob
 from airflow.models import errors
 from airflow.models.dag import DagModel
 from airflow.models.dagwarning import DagWarning
@@ -60,6 +62,7 @@ from airflow.utils.process_utils import (
     reap_process_group,
     set_new_process_group,
 )
+from airflow.utils.retries import retry_db_transaction
 from airflow.utils.session import NEW_SESSION, provide_session
 from airflow.utils.sqlalchemy import prohibit_commit, skip_locked, with_row_locks
 
@@ -84,9 +87,9 @@ class DagFileStat(NamedTuple):
 class DagParsingSignal(enum.Enum):
     """All signals sent to parser."""
 
-    AGENT_RUN_ONCE = 'agent_run_once'
-    TERMINATE_MANAGER = 'terminate_manager'
-    END_MANAGER = 'end_manager'
+    AGENT_RUN_ONCE = "agent_run_once"
+    TERMINATE_MANAGER = "terminate_manager"
+    END_MANAGER = "end_manager"
 
 
 class DagFileProcessorAgent(LoggingMixin, MultiprocessingStartMethodMixin):
@@ -118,7 +121,6 @@ class DagFileProcessorAgent(LoggingMixin, MultiprocessingStartMethodMixin):
         async_mode: bool,
     ):
         super().__init__()
-        self._file_path_queue: list[str] = []
         self._dag_directory: os.PathLike = dag_directory
         self._max_runs = max_runs
         self._processor_timeout = processor_timeout
@@ -227,8 +229,8 @@ class DagFileProcessorAgent(LoggingMixin, MultiprocessingStartMethodMixin):
         # Because this process may need custom configurations that cannot be shared,
         # e.g. RotatingFileHandler. And it can cause connection corruption if we
         # do not recreate the SQLA connection pool.
-        os.environ['CONFIG_PROCESSOR_MANAGER_LOGGER'] = 'True'
-        os.environ['AIRFLOW__LOGGING__COLORED_CONSOLE_LOG'] = 'False'
+        os.environ["CONFIG_PROCESSOR_MANAGER_LOGGER"] = "True"
+        os.environ["AIRFLOW__LOGGING__COLORED_CONSOLE_LOG"] = "False"
         # Replicating the behavior of how logging module was loaded
         # in logging_config.py
 
@@ -241,10 +243,10 @@ class DagFileProcessorAgent(LoggingMixin, MultiprocessingStartMethodMixin):
         # The issue that describes the problem and possible remediation is
         # at https://github.com/apache/airflow/issues/19934
 
-        importlib.reload(import_module(airflow.settings.LOGGING_CLASS_PATH.rsplit('.', 1)[0]))  # type: ignore
+        importlib.reload(import_module(airflow.settings.LOGGING_CLASS_PATH.rsplit(".", 1)[0]))  # type: ignore
         importlib.reload(airflow.settings)
         airflow.settings.initialize()
-        del os.environ['CONFIG_PROCESSOR_MANAGER_LOGGER']
+        del os.environ["CONFIG_PROCESSOR_MANAGER_LOGGER"]
         processor_manager = DagFileProcessorManager(
             dag_directory=dag_directory,
             max_runs=max_runs,
@@ -297,7 +299,7 @@ class DagFileProcessorAgent(LoggingMixin, MultiprocessingStartMethodMixin):
 
         parsing_stat_age = time.monotonic() - self._last_parsing_stat_received_at
         if parsing_stat_age > self._processor_timeout.total_seconds():
-            Stats.incr('dag_processing.manager_stalls')
+            Stats.incr("dag_processing.manager_stalls")
             self.log.error(
                 "DagFileProcessorManager (PID=%d) last sent a heartbeat %.2f seconds ago! Restarting it",
                 self._process.pid,
@@ -340,7 +342,7 @@ class DagFileProcessorAgent(LoggingMixin, MultiprocessingStartMethodMixin):
         :return:
         """
         if not self._process:
-            self.log.warning('Ending without manager process.')
+            self.log.warning("Ending without manager process.")
             return
         # Give the Manager some time to cleanly shut down, but not too long, as
         # it's better to finish sooner than wait for (non-critical) work to
@@ -378,10 +380,11 @@ class DagFileProcessorManager(LoggingMixin):
         pickle_dags: bool,
         signal_conn: MultiprocessingConnection | None = None,
         async_mode: bool = True,
+        job: BaseJob | None = None,
     ):
         super().__init__()
         self._file_paths: list[str] = []
-        self._file_path_queue: list[str] = []
+        self._file_path_queue: collections.deque[str] = collections.deque()
         self._max_runs = max_runs
         # signal_conn is None for dag_processor_standalone mode.
         self._direct_scheduler_conn = signal_conn
@@ -390,6 +393,7 @@ class DagFileProcessorManager(LoggingMixin):
         self._async_mode = async_mode
         self._parsing_start_time: int | None = None
         self._dag_directory = dag_directory
+        self._job = job
 
         # Set the signal conn in to non-blocking mode, so that attempting to
         # send when the buffer is full errors, rather than hangs for-ever
@@ -401,9 +405,9 @@ class DagFileProcessorManager(LoggingMixin):
             os.set_blocking(self._direct_scheduler_conn.fileno(), False)
 
         self.standalone_dag_processor = conf.getboolean("scheduler", "standalone_dag_processor")
-        self._parallelism = conf.getint('scheduler', 'parsing_processes')
+        self._parallelism = conf.getint("scheduler", "parsing_processes")
         if (
-            conf.get_mandatory_value('database', 'sql_alchemy_conn').startswith('sqlite')
+            conf.get_mandatory_value("database", "sql_alchemy_conn").startswith("sqlite")
             and self._parallelism > 1
         ):
             self.log.warning(
@@ -414,10 +418,10 @@ class DagFileProcessorManager(LoggingMixin):
             self._parallelism = 1
 
         # Parse and schedule each file no faster than this interval.
-        self._file_process_interval = conf.getint('scheduler', 'min_file_process_interval')
+        self._file_process_interval = conf.getint("scheduler", "min_file_process_interval")
         # How often to print out DAG file processing stats to the log. Default to
         # 30 seconds.
-        self.print_stats_interval = conf.getint('scheduler', 'print_stats_interval')
+        self.print_stats_interval = conf.getint("scheduler", "print_stats_interval")
 
         # Map from file path to the processor
         self._processors: dict[str, DagFileProcessorProcess] = {}
@@ -434,16 +438,16 @@ class DagFileProcessorManager(LoggingMixin):
         # Last time we cleaned up DAGs which are no longer in files
         self.last_deactivate_stale_dags_time = timezone.make_aware(datetime.fromtimestamp(0))
         # How often to check for DAGs which are no longer in files
-        self.deactivate_stale_dags_interval = conf.getint('scheduler', 'deactivate_stale_dags_interval')
+        self.parsing_cleanup_interval = conf.getint("scheduler", "parsing_cleanup_interval")
         # How long to wait before timing out a process to parse a DAG file
         self._processor_timeout = processor_timeout
         # How often to scan the DAGs directory for new files. Default to 5 minutes.
-        self.dag_dir_list_interval = conf.getint('scheduler', 'dag_dir_list_interval')
+        self.dag_dir_list_interval = conf.getint("scheduler", "dag_dir_list_interval")
 
         # Mapping file name and callbacks requests
         self._callback_to_execute: dict[str, list[CallbackRequest]] = defaultdict(list)
 
-        self._log = logging.getLogger('airflow.processor_manager')
+        self._log = logging.getLogger("airflow.processor_manager")
 
         self.waitables: dict[Any, MultiprocessingConnection | DagFileProcessorProcess] = (
             {
@@ -463,7 +467,7 @@ class DagFileProcessorManager(LoggingMixin):
     def _exit_gracefully(self, signum, frame):
         """Helper method to clean up DAG file processors to avoid leaving orphan processes."""
         self.log.info("Exiting gracefully upon receiving signal %s", signum)
-        self.log.debug("Current Stacktrace is: %s", '\n'.join(map(str, inspect.stack())))
+        self.log.debug("Current Stacktrace is: %s", "\n".join(map(str, inspect.stack())))
         self.terminate()
         self.end()
         self.log.debug("Finished terminating DAG processors.")
@@ -497,7 +501,7 @@ class DagFileProcessorManager(LoggingMixin):
         """
         now = timezone.utcnow()
         elapsed_time_since_refresh = (now - self.last_deactivate_stale_dags_time).total_seconds()
-        if elapsed_time_since_refresh > self.deactivate_stale_dags_interval:
+        if elapsed_time_since_refresh > self.parsing_cleanup_interval:
             last_parsed = {
                 fp: self.get_last_finish_time(fp) for fp in self.file_paths if self.get_last_finish_time(fp)
             }
@@ -554,6 +558,8 @@ class DagFileProcessorManager(LoggingMixin):
         while True:
             loop_start_time = time.monotonic()
             ready = multiprocessing.connection.wait(self.waitables.keys(), timeout=poll_time)
+            if self._job:
+                self._job.heartbeat()
             if self._direct_scheduler_conn is not None and self._direct_scheduler_conn in ready:
                 agent_signal = self._direct_scheduler_conn.recv()
 
@@ -601,7 +607,7 @@ class DagFileProcessorManager(LoggingMixin):
                 self._fetch_callbacks(max_callbacks_per_loop)
             self._deactivate_stale_dags()
             DagWarning.purge_inactive_dag_warnings()
-            self._refresh_dag_dir()
+            refreshed_dag_dir = self._refresh_dag_dir()
 
             self._kill_timed_out_processors()
 
@@ -610,6 +616,8 @@ class DagFileProcessorManager(LoggingMixin):
             if not self._file_path_queue:
                 self.emit_metrics()
                 self.prepare_file_path_queue()
+            elif refreshed_dag_dir:
+                self.add_new_file_path_to_queue()
 
             self.start_new_processes()
 
@@ -664,6 +672,10 @@ class DagFileProcessorManager(LoggingMixin):
 
     @provide_session
     def _fetch_callbacks(self, max_callbacks: int, session: Session = NEW_SESSION):
+        self._fetch_callbacks_with_retries(max_callbacks, session)
+
+    @retry_db_transaction
+    def _fetch_callbacks_with_retries(self, max_callbacks: int, session: Session):
         """Fetches callbacks from database and add them to the internal queue for execution."""
         self.log.debug("Fetching callbacks from the database.")
         with prohibit_commit(session) as guard:
@@ -710,10 +722,10 @@ class DagFileProcessorManager(LoggingMixin):
                 # Remove file paths matching request.full_filepath from self._file_path_queue
                 # Since we are already going to use that filepath to run callback,
                 # there is no need to have same file path again in the queue
-                self._file_path_queue = [
+                self._file_path_queue = collections.deque(
                     file_path for file_path in self._file_path_queue if file_path != request.full_filepath
-                ]
-            self._file_path_queue.insert(0, request.full_filepath)
+                )
+            self._file_path_queue.appendleft(request.full_filepath)
 
     def _refresh_dag_dir(self):
         """Refresh file paths from dag dir if we haven't done it for too long."""
@@ -739,14 +751,17 @@ class DagFileProcessorManager(LoggingMixin):
             dag_filelocs = []
             for fileloc in self._file_paths:
                 if not fileloc.endswith(".py") and zipfile.is_zipfile(fileloc):
-                    with zipfile.ZipFile(fileloc) as z:
-                        dag_filelocs.extend(
-                            [
-                                os.path.join(fileloc, info.filename)
-                                for info in z.infolist()
-                                if might_contain_dag(info.filename, True, z)
-                            ]
-                        )
+                    try:
+                        with zipfile.ZipFile(fileloc) as z:
+                            dag_filelocs.extend(
+                                [
+                                    os.path.join(fileloc, info.filename)
+                                    for info in z.infolist()
+                                    if might_contain_dag(info.filename, True, z)
+                                ]
+                            )
+                    except zipfile.BadZipFile as err:
+                        self.log.error("There was an err accessing %s, %s", fileloc, err)
                 else:
                     dag_filelocs.append(fileloc)
 
@@ -760,6 +775,9 @@ class DagFileProcessorManager(LoggingMixin):
 
             DagCode.remove_deleted_code(dag_filelocs)
 
+            return True
+        return False
+
     def _print_stat(self):
         """Occasionally print out stats about how fast the files are getting processed"""
         if 0 < self.print_stats_interval < time.monotonic() - self.last_stat_print_time:
@@ -777,7 +795,7 @@ class DagFileProcessorManager(LoggingMixin):
         query = session.query(errors.ImportError)
         if self._file_paths:
             query = query.filter(~errors.ImportError.filename.in_(self._file_paths))
-        query.delete(synchronize_session='fetch')
+        query.delete(synchronize_session="fetch")
         session.commit()
 
     def _log_file_processing_stats(self, known_file_paths):
@@ -805,7 +823,7 @@ class DagFileProcessorManager(LoggingMixin):
             num_dags = self.get_last_dag_count(file_path)
             num_errors = self.get_last_error_count(file_path)
             file_name = os.path.basename(file_path)
-            file_name = os.path.splitext(file_name)[0].replace(os.sep, '.')
+            file_name = os.path.splitext(file_name)[0].replace(os.sep, ".")
 
             processor_pid = self.get_pid(file_path)
             processor_start_time = self.get_start_time(file_path)
@@ -813,7 +831,7 @@ class DagFileProcessorManager(LoggingMixin):
             last_run = self.get_last_finish_time(file_path)
             if last_run:
                 seconds_ago = (now - last_run).total_seconds()
-                Stats.gauge(f'dag_processing.last_run.seconds_ago.{file_name}', seconds_ago)
+                Stats.gauge(f"dag_processing.last_run.seconds_ago.{file_name}", seconds_ago)
 
             rows.append((file_path, processor_pid, runtime, num_dags, num_errors, last_runtime, last_run))
 
@@ -845,89 +863,80 @@ class DagFileProcessorManager(LoggingMixin):
 
         self.log.info(log_str)
 
-    def get_pid(self, file_path):
+    def get_pid(self, file_path) -> int | None:
         """
         :param file_path: the path to the file that's being processed
         :return: the PID of the process processing the given file or None if
             the specified file is not being processed
-        :rtype: int
         """
         if file_path in self._processors:
             return self._processors[file_path].pid
         return None
 
-    def get_all_pids(self):
+    def get_all_pids(self) -> list[int]:
         """
+        Get all pids.
+
         :return: a list of the PIDs for the processors that are running
-        :rtype: List[int]
         """
         return [x.pid for x in self._processors.values()]
 
-    def get_last_runtime(self, file_path):
+    def get_last_runtime(self, file_path) -> float | None:
         """
         :param file_path: the path to the file that was processed
         :return: the runtime (in seconds) of the process of the last run, or
             None if the file was never processed.
-        :rtype: float
         """
         stat = self._file_stats.get(file_path)
         return stat.last_duration.total_seconds() if stat and stat.last_duration else None
 
-    def get_last_dag_count(self, file_path):
+    def get_last_dag_count(self, file_path) -> int | None:
         """
         :param file_path: the path to the file that was processed
         :return: the number of dags loaded from that file, or None if the file
             was never processed.
-        :rtype: int
         """
         stat = self._file_stats.get(file_path)
         return stat.num_dags if stat else None
 
-    def get_last_error_count(self, file_path):
+    def get_last_error_count(self, file_path) -> int | None:
         """
         :param file_path: the path to the file that was processed
         :return: the number of import errors from processing, or None if the file
             was never processed.
-        :rtype: int
         """
         stat = self._file_stats.get(file_path)
         return stat.import_errors if stat else None
 
-    def get_last_finish_time(self, file_path):
+    def get_last_finish_time(self, file_path) -> datetime | None:
         """
         :param file_path: the path to the file that was processed
         :return: the finish time of the process of the last run, or None if the
             file was never processed.
-        :rtype: datetime
         """
         stat = self._file_stats.get(file_path)
         return stat.last_finish_time if stat else None
 
-    def get_start_time(self, file_path):
+    def get_start_time(self, file_path) -> datetime | None:
         """
         :param file_path: the path to the file that's being processed
         :return: the start time of the process that's processing the
             specified file or None if the file is not currently being processed
-        :rtype: datetime
         """
         if file_path in self._processors:
             return self._processors[file_path].start_time
         return None
 
-    def get_run_count(self, file_path):
+    def get_run_count(self, file_path) -> int:
         """
         :param file_path: the path to the file that's being processed
         :return: the number of times the given file has been parsed
-        :rtype: int
         """
         stat = self._file_stats.get(file_path)
         return stat.run_count if stat else 0
 
     def get_dag_directory(self) -> str:
-        """
-        Returns the dag_director as a string.
-        :rtype: str
-        """
+        """Returns the dag_director as a string."""
         if isinstance(self._dag_directory, Path):
             return str(self._dag_directory.resolve())
         else:
@@ -941,7 +950,7 @@ class DagFileProcessorManager(LoggingMixin):
         :return: None
         """
         self._file_paths = new_file_paths
-        self._file_path_queue = [x for x in self._file_path_queue if x in new_file_paths]
+        self._file_path_queue = collections.deque(x for x in self._file_path_queue if x in new_file_paths)
         # Stop processors that are working on deleted files
         filtered_processors = {}
         for file_path, processor in self._processors.items():
@@ -949,9 +958,15 @@ class DagFileProcessorManager(LoggingMixin):
                 filtered_processors[file_path] = processor
             else:
                 self.log.warning("Stopping processor for %s", file_path)
-                Stats.decr('dag_processing.processes')
+                Stats.decr("dag_processing.processes")
                 processor.terminate()
                 self._file_stats.pop(file_path)
+
+        to_remove = set(self._file_stats.keys()) - set(self._file_paths)
+        for key in to_remove:
+            # Remove the stats for any dag files that don't exist anymore
+            del self._file_stats[key]
+
         self._processors = filtered_processors
 
     def wait_until_finished(self):
@@ -962,7 +977,7 @@ class DagFileProcessorManager(LoggingMixin):
 
     def _collect_results_from_processor(self, processor) -> None:
         self.log.debug("Processor for %s finished", processor.file_path)
-        Stats.decr('dag_processing.processes')
+        Stats.decr("dag_processing.processes")
         last_finish_time = timezone.utcnow()
 
         if processor.result is not None:
@@ -984,8 +999,8 @@ class DagFileProcessorManager(LoggingMixin):
         )
         self._file_stats[processor.file_path] = stat
 
-        file_name = os.path.splitext(os.path.basename(processor.file_path))[0].replace(os.sep, '.')
-        Stats.timing(f'dag_processing.last_duration.{file_name}', last_duration)
+        file_name = os.path.splitext(os.path.basename(processor.file_path))[0].replace(os.sep, ".")
+        Stats.timing(f"dag_processing.last_duration.{file_name}", last_duration)
 
     def collect_results(self) -> None:
         """Collect the result from any finished DAG processors"""
@@ -1019,7 +1034,7 @@ class DagFileProcessorManager(LoggingMixin):
     def start_new_processes(self):
         """Start more processors if we have enough slots and files to process"""
         while self._parallelism - len(self._processors) > 0 and self._file_path_queue:
-            file_path = self._file_path_queue.pop(0)
+            file_path = self._file_path_queue.popleft()
             # Stop creating duplicate processor i.e. processor with the same filepath
             if file_path in self._processors.keys():
                 continue
@@ -1034,13 +1049,23 @@ class DagFileProcessorManager(LoggingMixin):
             )
 
             del self._callback_to_execute[file_path]
-            Stats.incr('dag_processing.processes')
+            Stats.incr("dag_processing.processes")
 
             processor.start()
             self.log.debug("Started a process (PID: %s) to generate tasks for %s", processor.pid, file_path)
             self._processors[file_path] = processor
             self.waitables[processor.waitable_handle] = processor
 
+    def add_new_file_path_to_queue(self):
+        for file_path in self.file_paths:
+            if file_path not in self._file_stats:
+                # We found new file after refreshing dir. add to parsing queue at start
+                self.log.info("Adding new file %s to parsing queue", file_path)
+                self._file_stats[file_path] = DagFileStat(
+                    num_dags=0, import_errors=0, last_finish_time=None, last_duration=None, run_count=0
+                )
+                self._file_path_queue.appendleft(file_path)
+
     def prepare_file_path_queue(self):
         """Generate more file paths to process. Result are saved in _file_path_queue."""
         self._parsing_start_time = time.perf_counter()
@@ -1057,6 +1082,7 @@ class DagFileProcessorManager(LoggingMixin):
         is_mtime_mode = list_mode == "modified_time"
 
         file_paths_recently_processed = []
+        file_paths_to_stop_watching = set()
         for file_path in self._file_paths:
 
             if is_mtime_mode:
@@ -1064,6 +1090,8 @@ class DagFileProcessorManager(LoggingMixin):
                     files_with_mtime[file_path] = os.path.getmtime(file_path)
                 except FileNotFoundError:
                     self.log.warning("Skipping processing of missing file: %s", file_path)
+                    self._file_stats.pop(file_path, None)
+                    file_paths_to_stop_watching.add(file_path)
                     continue
                 file_modified_time = timezone.make_aware(datetime.fromtimestamp(files_with_mtime[file_path]))
             else:
@@ -1092,12 +1120,18 @@ class DagFileProcessorManager(LoggingMixin):
             # set of files. Since we set the seed, the sort order will remain same per host
             random.Random(get_hostname()).shuffle(file_paths)
 
+        if file_paths_to_stop_watching:
+            self.set_file_paths(
+                [path for path in self._file_paths if path not in file_paths_to_stop_watching]
+            )
+
         files_paths_at_run_limit = [
             file_path for file_path, stat in self._file_stats.items() if stat.run_count == self._max_runs
         ]
 
         file_paths_to_exclude = set(file_paths_in_progress).union(
-            file_paths_recently_processed, files_paths_at_run_limit
+            file_paths_recently_processed,
+            files_paths_at_run_limit,
         )
 
         # Do not convert the following list to set as set does not preserve the order
@@ -1115,12 +1149,11 @@ class DagFileProcessorManager(LoggingMixin):
 
         self.log.debug("Queuing the following files for processing:\n\t%s", "\n\t".join(files_paths_to_queue))
 
+        default = DagFileStat(
+            num_dags=0, import_errors=0, last_finish_time=None, last_duration=None, run_count=0
+        )
         for file_path in files_paths_to_queue:
-            if file_path not in self._file_stats:
-                self._file_stats[file_path] = DagFileStat(
-                    num_dags=0, import_errors=0, last_finish_time=None, last_duration=None, run_count=0
-                )
-
+            self._file_stats.setdefault(file_path, default)
         self._file_path_queue.extend(files_paths_to_queue)
 
     def _kill_timed_out_processors(self):
@@ -1136,16 +1169,25 @@ class DagFileProcessorManager(LoggingMixin):
                     processor.pid,
                     processor.start_time.isoformat(),
                 )
-                Stats.decr('dag_processing.processes')
-                Stats.incr('dag_processing.processor_timeouts')
-                # TODO: Remove after Airflow 2.0
-                Stats.incr('dag_file_processor_timeouts')
+                Stats.decr("dag_processing.processes")
+                Stats.incr("dag_processing.processor_timeouts")
+                # Deprecated; may be removed in a future Airflow release.
+                Stats.incr("dag_file_processor_timeouts")
                 processor.kill()
 
                 # Clean up processor references
                 self.waitables.pop(processor.waitable_handle)
                 processors_to_remove.append(file_path)
 
+                stat = DagFileStat(
+                    num_dags=0,
+                    import_errors=1,
+                    last_finish_time=now,
+                    last_duration=duration,
+                    run_count=self.get_run_count(file_path) + 1,
+                )
+                self._file_stats[processor.file_path] = stat
+
         # Clean up `self._processors` after iterating over it
         for proc in processors_to_remove:
             self._processors.pop(proc)
@@ -1167,7 +1209,7 @@ class DagFileProcessorManager(LoggingMixin):
         :return: None
         """
         for processor in self._processors.values():
-            Stats.decr('dag_processing.processes')
+            Stats.decr("dag_processing.processes")
             processor.terminate()
 
     def end(self):
@@ -1187,10 +1229,10 @@ class DagFileProcessorManager(LoggingMixin):
         all files have been parsed.
         """
         parse_time = time.perf_counter() - self._parsing_start_time
-        Stats.gauge('dag_processing.total_parse_time', parse_time)
-        Stats.gauge('dagbag_size', sum(stat.num_dags for stat in self._file_stats.values()))
+        Stats.gauge("dag_processing.total_parse_time", parse_time)
+        Stats.gauge("dagbag_size", sum(stat.num_dags for stat in self._file_stats.values()))
         Stats.gauge(
-            'dag_processing.import_errors', sum(stat.import_errors for stat in self._file_stats.values())
+            "dag_processing.import_errors", sum(stat.import_errors for stat in self._file_stats.values())
         )
 
     @property
