@@ -15,17 +15,16 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """Serialized DAG table in database."""
+from __future__ import annotations
 
 import hashlib
 import logging
 import zlib
 from datetime import datetime, timedelta
-from typing import Any, Dict, List, Optional
 
 import sqlalchemy_jsonfield
-from sqlalchemy import BigInteger, Column, Index, LargeBinary, String, and_
+from sqlalchemy import BigInteger, Column, Index, LargeBinary, String, and_, or_
 from sqlalchemy.orm import Session, backref, foreign, relationship
 from sqlalchemy.sql.expression import func, literal
 
@@ -62,23 +61,24 @@ class SerializedDagModel(Base):
     it solves the webserver scalability issue.
     """
 
-    __tablename__ = 'serialized_dag'
+    __tablename__ = "serialized_dag"
 
     dag_id = Column(String(ID_LEN), primary_key=True)
     fileloc = Column(String(2000), nullable=False)
     # The max length of fileloc exceeds the limit of indexing.
-    fileloc_hash = Column(BigInteger, nullable=False)
-    _data = Column('data', sqlalchemy_jsonfield.JSONField(json=json), nullable=True)
-    _data_compressed = Column('data_compressed', LargeBinary, nullable=True)
+    fileloc_hash = Column(BigInteger(), nullable=False)
+    _data = Column("data", sqlalchemy_jsonfield.JSONField(json=json), nullable=True)
+    _data_compressed = Column("data_compressed", LargeBinary, nullable=True)
     last_updated = Column(UtcDateTime, nullable=False)
     dag_hash = Column(String(32), nullable=False)
+    processor_subdir = Column(String(2000), nullable=True)
 
-    __table_args__ = (Index('idx_fileloc_hash', fileloc_hash, unique=False),)
+    __table_args__ = (Index("idx_fileloc_hash", fileloc_hash, unique=False),)
 
     dag_runs = relationship(
         DagRun,
         primaryjoin=dag_id == foreign(DagRun.dag_id),  # type: ignore
-        backref=backref('serialized_dag', uselist=False, innerjoin=True),
+        backref=backref("serialized_dag", uselist=False, innerjoin=True),
     )
 
     dag_model = relationship(
@@ -87,16 +87,17 @@ class SerializedDagModel(Base):
         foreign_keys=dag_id,
         uselist=False,
         innerjoin=True,
-        backref=backref('serialized_dag', uselist=False, innerjoin=True),
+        backref=backref("serialized_dag", uselist=False, innerjoin=True),
     )
 
     load_op_links = True
 
-    def __init__(self, dag: DAG):
+    def __init__(self, dag: DAG, processor_subdir: str | None = None):
         self.dag_id = dag.dag_id
         self.fileloc = dag.fileloc
         self.fileloc_hash = DagCode.dag_fileloc_hash(self.fileloc)
         self.last_updated = timezone.utcnow()
+        self.processor_subdir = processor_subdir
 
         dag_data = SerializedDAG.to_dict(dag)
         dag_data_json = json.dumps(dag_data, sort_keys=True).encode("utf-8")
@@ -119,7 +120,13 @@ class SerializedDagModel(Base):
 
     @classmethod
     @provide_session
-    def write_dag(cls, dag: DAG, min_update_interval: Optional[int] = None, session: Session = None) -> bool:
+    def write_dag(
+        cls,
+        dag: DAG,
+        min_update_interval: int | None = None,
+        processor_subdir: str | None = None,
+        session: Session = None,
+    ) -> bool:
         """Serializes a DAG and writes it into database.
         If the record already exists, it checks if the Serialized DAG changed or not. If it is
         changed, it updates the record, ignores otherwise.
@@ -142,19 +149,21 @@ class SerializedDagModel(Base):
                         (timezone.utcnow() - timedelta(seconds=min_update_interval)) < cls.last_updated,
                     )
                 )
-                .first()
-                is not None
+                .scalar()
             ):
-                # TODO: .first() is not None can be changed to .scalar() once we update to sqlalchemy 1.4+
-                # as the associated sqlalchemy bug for MySQL was fixed
-                # related issue : https://github.com/sqlalchemy/sqlalchemy/issues/5481
                 return False
 
         log.debug("Checking if DAG (%s) changed", dag.dag_id)
-        new_serialized_dag = cls(dag)
-        serialized_dag_hash_from_db = session.query(cls.dag_hash).filter(cls.dag_id == dag.dag_id).scalar()
+        new_serialized_dag = cls(dag, processor_subdir)
+        serialized_dag_db = (
+            session.query(cls.dag_hash, cls.processor_subdir).filter(cls.dag_id == dag.dag_id).first()
+        )
 
-        if serialized_dag_hash_from_db == new_serialized_dag.dag_hash:
+        if (
+            serialized_dag_db is not None
+            and serialized_dag_db.dag_hash == new_serialized_dag.dag_hash
+            and serialized_dag_db.processor_subdir == new_serialized_dag.processor_subdir
+        ):
             log.debug("Serialized DAG (%s) is unchanged. Skipping writing to DB", dag.dag_id)
             return False
 
@@ -165,7 +174,7 @@ class SerializedDagModel(Base):
 
     @classmethod
     @provide_session
-    def read_all_dags(cls, session: Session = None) -> Dict[str, 'SerializedDAG']:
+    def read_all_dags(cls, session: Session = None) -> dict[str, SerializedDAG]:
         """Reads all DAGs in serialized_dag table.
 
         :param session: ORM Session
@@ -206,7 +215,7 @@ class SerializedDagModel(Base):
         SerializedDAG._load_operator_extra_links = self.load_op_links
 
         if isinstance(self.data, dict):
-            dag = SerializedDAG.from_dict(self.data)  # type: Any
+            dag = SerializedDAG.from_dict(self.data)
         else:
             dag = SerializedDAG.from_json(self.data)
         return dag
@@ -222,7 +231,9 @@ class SerializedDagModel(Base):
 
     @classmethod
     @provide_session
-    def remove_deleted_dags(cls, alive_dag_filelocs: List[str], session=None):
+    def remove_deleted_dags(
+        cls, alive_dag_filelocs: list[str], processor_subdir: str | None = None, session=None
+    ):
         """Deletes DAGs not included in alive_dag_filelocs.
 
         :param alive_dag_filelocs: file paths of alive DAGs
@@ -236,7 +247,14 @@ class SerializedDagModel(Base):
 
         session.execute(
             cls.__table__.delete().where(
-                and_(cls.fileloc_hash.notin_(alive_fileloc_hashes), cls.fileloc.notin_(alive_dag_filelocs))
+                and_(
+                    cls.fileloc_hash.notin_(alive_fileloc_hashes),
+                    cls.fileloc.notin_(alive_dag_filelocs),
+                    or_(
+                        cls.processor_subdir.is_(None),
+                        cls.processor_subdir == processor_subdir,
+                    ),
+                )
             )
         )
 
@@ -252,7 +270,15 @@ class SerializedDagModel(Base):
 
     @classmethod
     @provide_session
-    def get(cls, dag_id: str, session: Session = None) -> Optional['SerializedDagModel']:
+    def get_dag(cls, dag_id: str, session: Session = None) -> SerializedDAG | None:
+        row = cls.get(dag_id, session=session)
+        if row:
+            return row.dag
+        return None
+
+    @classmethod
+    @provide_session
+    def get(cls, dag_id: str, session: Session = None) -> SerializedDagModel | None:
         """
         Get the SerializedDAG for the given dag ID.
         It will cope with being passed the ID of a subdag by looking up the
@@ -273,7 +299,7 @@ class SerializedDagModel(Base):
 
     @staticmethod
     @provide_session
-    def bulk_sync_to_db(dags: List[DAG], session: Session = None):
+    def bulk_sync_to_db(dags: list[DAG], processor_subdir: str | None = None, session: Session = None):
         """
         Saves DAGs as Serialized DAG objects in the database. Each
         DAG is saved in a separate database query.
@@ -285,12 +311,15 @@ class SerializedDagModel(Base):
         for dag in dags:
             if not dag.is_subdag:
                 SerializedDagModel.write_dag(
-                    dag, min_update_interval=MIN_SERIALIZED_DAG_UPDATE_INTERVAL, session=session
+                    dag=dag,
+                    min_update_interval=MIN_SERIALIZED_DAG_UPDATE_INTERVAL,
+                    processor_subdir=processor_subdir,
+                    session=session,
                 )
 
     @classmethod
     @provide_session
-    def get_last_updated_datetime(cls, dag_id: str, session: Session = None) -> Optional[datetime]:
+    def get_last_updated_datetime(cls, dag_id: str, session: Session = None) -> datetime | None:
         """
         Get the date when the Serialized DAG associated to DAG was last updated
         in serialized_dag table
@@ -302,7 +331,7 @@ class SerializedDagModel(Base):
 
     @classmethod
     @provide_session
-    def get_max_last_updated_datetime(cls, session: Session = None) -> Optional[datetime]:
+    def get_max_last_updated_datetime(cls, session: Session = None) -> datetime | None:
         """
         Get the maximum date when any DAG was last updated in serialized_dag table
 
@@ -312,20 +341,19 @@ class SerializedDagModel(Base):
 
     @classmethod
     @provide_session
-    def get_latest_version_hash(cls, dag_id: str, session: Session = None) -> Optional[str]:
+    def get_latest_version_hash(cls, dag_id: str, session: Session = None) -> str | None:
         """
         Get the latest DAG version for a given DAG ID.
 
         :param dag_id: DAG ID
         :param session: ORM Session
         :return: DAG Hash, or None if the DAG is not found
-        :rtype: str | None
         """
         return session.query(cls.dag_hash).filter(cls.dag_id == dag_id).scalar()
 
     @classmethod
     @provide_session
-    def get_dag_dependencies(cls, session: Session = None) -> Dict[str, List['DagDependency']]:
+    def get_dag_dependencies(cls, session: Session = None) -> dict[str, list[DagDependency]]:
         """
         Get the dependencies between DAGs
 
