@@ -15,35 +15,36 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Base task runner"""
+"""Base task runner."""
+from __future__ import annotations
+
 import os
 import subprocess
 import threading
 
+from airflow.utils.dag_parsing_context import _airflow_parsing_context_manager
 from airflow.utils.platform import IS_WINDOWS
 
 if not IS_WINDOWS:
     # ignored to avoid flake complaining on Linux
     from pwd import getpwnam  # noqa
 
-from tempfile import NamedTemporaryFile
-from typing import Optional, Union
 
 from airflow.configuration import conf
 from airflow.exceptions import AirflowConfigException
-from airflow.models.taskinstance import load_error_file
 from airflow.utils.configuration import tmp_configuration_copy
 from airflow.utils.log.logging_mixin import LoggingMixin
 from airflow.utils.net import get_hostname
 from airflow.utils.platform import getuser
 
-PYTHONPATH_VAR = 'PYTHONPATH'
+PYTHONPATH_VAR = "PYTHONPATH"
 
 
 class BaseTaskRunner(LoggingMixin):
     """
-    Runs Airflow task instances by invoking the `airflow tasks run` command with raw
-    mode enabled in a subprocess.
+    Runs Airflow task instances via CLI.
+
+    Invoke the `airflow tasks run` command with raw mode enabled in a subprocess.
 
     :param local_task_job: The local task job associated with running the
         associated task instance.
@@ -59,12 +60,10 @@ class BaseTaskRunner(LoggingMixin):
             self.run_as_user = self._task_instance.run_as_user
         else:
             try:
-                self.run_as_user = conf.get('core', 'default_impersonation')
+                self.run_as_user = conf.get("core", "default_impersonation")
             except AirflowConfigException:
                 self.run_as_user = None
 
-        self._error_file = NamedTemporaryFile(delete=True)
-
         # Add sudo commands to change user if we need to. Needed to handle SubDagOperator
         # case using a SequentialExecutor.
         self.log.debug("Planning to run as the %s user", self.run_as_user)
@@ -76,16 +75,14 @@ class BaseTaskRunner(LoggingMixin):
             cfg_path = tmp_configuration_copy(chmod=0o600, include_env=True, include_cmds=True)
 
             # Give ownership of file to user; only they can read and write
-            subprocess.check_call(
-                ['sudo', 'chown', self.run_as_user, cfg_path, self._error_file.name], close_fds=True
-            )
+            subprocess.check_call(["sudo", "chown", self.run_as_user, cfg_path], close_fds=True)
 
             # propagate PYTHONPATH environment variable
-            pythonpath_value = os.environ.get(PYTHONPATH_VAR, '')
-            popen_prepend = ['sudo', '-E', '-H', '-u', self.run_as_user]
+            pythonpath_value = os.environ.get(PYTHONPATH_VAR, "")
+            popen_prepend = ["sudo", "-E", "-H", "-u", self.run_as_user]
 
             if pythonpath_value:
-                popen_prepend.append(f'{PYTHONPATH_VAR}={pythonpath_value}')
+                popen_prepend.append(f"{PYTHONPATH_VAR}={pythonpath_value}")
 
         else:
             # Always provide a copy of the configuration file settings. Since
@@ -95,71 +92,65 @@ class BaseTaskRunner(LoggingMixin):
             cfg_path = tmp_configuration_copy(chmod=0o600, include_env=False, include_cmds=False)
 
         self._cfg_path = cfg_path
-        self._command = (
-            popen_prepend
-            + self._task_instance.command_as_list(
-                raw=True,
-                pickle_id=local_task_job.pickle_id,
-                mark_success=local_task_job.mark_success,
-                job_id=local_task_job.id,
-                pool=local_task_job.pool,
-                cfg_path=cfg_path,
-            )
-            + ["--error-file", self._error_file.name]
+        self._command = popen_prepend + self._task_instance.command_as_list(
+            raw=True,
+            pickle_id=local_task_job.pickle_id,
+            mark_success=local_task_job.mark_success,
+            job_id=local_task_job.id,
+            pool=local_task_job.pool,
+            cfg_path=cfg_path,
         )
         self.process = None
 
-    def deserialize_run_error(self) -> Optional[Union[str, Exception]]:
-        """Return task runtime error if its written to provided error file."""
-        return load_error_file(self._error_file)
-
     def _read_task_logs(self, stream):
         while True:
             line = stream.readline()
             if isinstance(line, bytes):
-                line = line.decode('utf-8')
+                line = line.decode("utf-8")
             if not line:
                 break
             self.log.info(
-                'Job %s: Subtask %s %s',
+                "Job %s: Subtask %s %s",
                 self._task_instance.job_id,
                 self._task_instance.task_id,
-                line.rstrip('\n'),
+                line.rstrip("\n"),
             )
 
-    def run_command(self, run_with=None):
+    def run_command(self, run_with=None) -> subprocess.Popen:
         """
         Run the task command.
 
         :param run_with: list of tokens to run the task command with e.g. ``['bash', '-c']``
         :return: the process that was run
-        :rtype: subprocess.Popen
         """
         run_with = run_with or []
         full_cmd = run_with + self._command
 
         self.log.info("Running on host: %s", get_hostname())
-        self.log.info('Running: %s', full_cmd)
-
-        if IS_WINDOWS:
-            proc = subprocess.Popen(
-                full_cmd,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.STDOUT,
-                universal_newlines=True,
-                close_fds=True,
-                env=os.environ.copy(),
-            )
-        else:
-            proc = subprocess.Popen(
-                full_cmd,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.STDOUT,
-                universal_newlines=True,
-                close_fds=True,
-                env=os.environ.copy(),
-                preexec_fn=os.setsid,
-            )
+        self.log.info("Running: %s", full_cmd)
+        with _airflow_parsing_context_manager(
+            dag_id=self._task_instance.dag_id,
+            task_id=self._task_instance.task_id,
+        ):
+            if IS_WINDOWS:
+                proc = subprocess.Popen(
+                    full_cmd,
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.STDOUT,
+                    universal_newlines=True,
+                    close_fds=True,
+                    env=os.environ.copy(),
+                )
+            else:
+                proc = subprocess.Popen(
+                    full_cmd,
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.STDOUT,
+                    universal_newlines=True,
+                    close_fds=True,
+                    env=os.environ.copy(),
+                    preexec_fn=os.setsid,
+                )
 
         # Start daemon thread to read subprocess logging output
         log_reader = threading.Thread(
@@ -174,11 +165,12 @@ class BaseTaskRunner(LoggingMixin):
         """Start running the task instance in a subprocess."""
         raise NotImplementedError()
 
-    def return_code(self, timeout: int = 0) -> Optional[int]:
+    def return_code(self, timeout: int = 0) -> int | None:
         """
+        Extract the return code.
+
         :return: The return code associated with running the task instance or
             None if the task is not yet done.
-        :rtype: int
         """
         raise NotImplementedError()
 
@@ -190,12 +182,6 @@ class BaseTaskRunner(LoggingMixin):
         """A callback that should be called when this is done running."""
         if self._cfg_path and os.path.isfile(self._cfg_path):
             if self.run_as_user:
-                subprocess.call(['sudo', 'rm', self._cfg_path], close_fds=True)
+                subprocess.call(["sudo", "rm", self._cfg_path], close_fds=True)
             else:
                 os.remove(self._cfg_path)
-        try:
-            self._error_file.close()
-        except FileNotFoundError:
-            # The subprocess has deleted this file before we do
-            # so we ignore
-            pass
