@@ -25,6 +25,7 @@ from flask import Flask
 from flask_appbuilder import SQLA
 from flask_caching import Cache
 from flask_wtf.csrf import CSRFProtect
+from markupsafe import Markup
 from sqlalchemy.engine.url import make_url
 
 from airflow import settings
@@ -32,14 +33,18 @@ from airflow.configuration import conf
 from airflow.exceptions import AirflowConfigException, RemovedInAirflow3Warning
 from airflow.logging_config import configure_logging
 from airflow.models import import_all_models
-from airflow.utils.json import AirflowJsonEncoder
+from airflow.utils.json import AirflowJsonProvider
 from airflow.www.extensions.init_appbuilder import init_appbuilder
 from airflow.www.extensions.init_appbuilder_links import init_appbuilder_links
 from airflow.www.extensions.init_dagbag import init_dagbag
 from airflow.www.extensions.init_jinja_globals import init_jinja_globals
 from airflow.www.extensions.init_manifest_files import configure_manifest_files
 from airflow.www.extensions.init_robots import init_robots
-from airflow.www.extensions.init_security import init_api_experimental_auth, init_xframe_protection
+from airflow.www.extensions.init_security import (
+    init_api_experimental_auth,
+    init_check_user_active,
+    init_xframe_protection,
+)
 from airflow.www.extensions.init_session import init_airflow_session_interface
 from airflow.www.extensions.init_views import (
     init_api_connexion,
@@ -65,34 +70,42 @@ def sync_appbuilder_roles(flask_app):
     # Otherwise, when the name of a view or menu is changed, the framework
     # will add the new Views and Menus names to the backend, but will not
     # delete the old ones.
-    if conf.getboolean('webserver', 'UPDATE_FAB_PERMS'):
+    if conf.getboolean("webserver", "UPDATE_FAB_PERMS"):
         flask_app.appbuilder.sm.sync_roles()
 
 
 def create_app(config=None, testing=False):
     """Create a new instance of Airflow WWW app"""
     flask_app = Flask(__name__)
-    flask_app.secret_key = conf.get('webserver', 'SECRET_KEY')
+    flask_app.secret_key = conf.get("webserver", "SECRET_KEY")
 
-    flask_app.config['PERMANENT_SESSION_LIFETIME'] = timedelta(minutes=settings.get_session_lifetime_config())
+    flask_app.config["PERMANENT_SESSION_LIFETIME"] = timedelta(minutes=settings.get_session_lifetime_config())
     flask_app.config.from_pyfile(settings.WEBSERVER_CONFIG, silent=True)
-    flask_app.config['APP_NAME'] = conf.get(section="webserver", key="instance_name", fallback="Airflow")
-    flask_app.config['TESTING'] = testing
-    flask_app.config['SQLALCHEMY_DATABASE_URI'] = conf.get('database', 'SQL_ALCHEMY_CONN')
+    flask_app.config["TESTING"] = testing
+    flask_app.config["SQLALCHEMY_DATABASE_URI"] = conf.get("database", "SQL_ALCHEMY_CONN")
 
-    url = make_url(flask_app.config['SQLALCHEMY_DATABASE_URI'])
-    if url.drivername == 'sqlite' and url.database and not url.database.startswith('/'):
+    instance_name = conf.get(section="webserver", key="instance_name", fallback="Airflow")
+    instance_name_has_markup = conf.getboolean(
+        section="webserver", key="instance_name_has_markup", fallback=False
+    )
+    if instance_name_has_markup:
+        instance_name = Markup(instance_name).striptags()
+
+    flask_app.config["APP_NAME"] = instance_name
+
+    url = make_url(flask_app.config["SQLALCHEMY_DATABASE_URI"])
+    if url.drivername == "sqlite" and url.database and not url.database.startswith("/"):
         raise AirflowConfigException(
             f'Cannot use relative path: `{conf.get("database", "SQL_ALCHEMY_CONN")}` to connect to sqlite. '
-            'Please use absolute path such as `sqlite:////tmp/airflow.db`.'
+            "Please use absolute path such as `sqlite:////tmp/airflow.db`."
         )
 
-    flask_app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
+    flask_app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = False
 
-    flask_app.config['SESSION_COOKIE_HTTPONLY'] = True
-    flask_app.config['SESSION_COOKIE_SECURE'] = conf.getboolean('webserver', 'COOKIE_SECURE')
+    flask_app.config["SESSION_COOKIE_HTTPONLY"] = True
+    flask_app.config["SESSION_COOKIE_SECURE"] = conf.getboolean("webserver", "COOKIE_SECURE")
 
-    cookie_samesite_config = conf.get('webserver', 'COOKIE_SAMESITE')
+    cookie_samesite_config = conf.get("webserver", "COOKIE_SAMESITE")
     if cookie_samesite_config == "":
         warnings.warn(
             "Old deprecated value found for `cookie_samesite` option in `[webserver]` section. "
@@ -100,16 +113,17 @@ def create_app(config=None, testing=False):
             RemovedInAirflow3Warning,
         )
         cookie_samesite_config = "Lax"
-    flask_app.config['SESSION_COOKIE_SAMESITE'] = cookie_samesite_config
+    flask_app.config["SESSION_COOKIE_SAMESITE"] = cookie_samesite_config
 
     if config:
         flask_app.config.from_mapping(config)
 
-    if 'SQLALCHEMY_ENGINE_OPTIONS' not in flask_app.config:
-        flask_app.config['SQLALCHEMY_ENGINE_OPTIONS'] = settings.prepare_engine_args()
+    if "SQLALCHEMY_ENGINE_OPTIONS" not in flask_app.config:
+        flask_app.config["SQLALCHEMY_ENGINE_OPTIONS"] = settings.prepare_engine_args()
 
     # Configure the JSON encoder used by `|tojson` filter from Flask
-    flask_app.json_provider_class = AirflowJsonEncoder
+    flask_app.json_provider_class = AirflowJsonProvider
+    flask_app.json = AirflowJsonProvider(flask_app)
 
     csrf.init_app(flask_app)
 
@@ -125,7 +139,7 @@ def create_app(config=None, testing=False):
 
     init_robots(flask_app)
 
-    cache_config = {'CACHE_TYPE': 'flask_caching.backends.filesystem', 'CACHE_DIR': gettempdir()}
+    cache_config = {"CACHE_TYPE": "flask_caching.backends.filesystem", "CACHE_DIR": gettempdir()}
     Cache(app=flask_app, config=cache_config)
 
     init_flash_views(flask_app)
@@ -151,6 +165,7 @@ def create_app(config=None, testing=False):
         init_jinja_globals(flask_app)
         init_xframe_protection(flask_app)
         init_airflow_session_interface(flask_app)
+        init_check_user_active(flask_app)
     return flask_app
 
 
