@@ -25,21 +25,17 @@ import {
   Tbody,
   Box,
   Thead,
-  Flex,
   IconButton,
 } from '@chakra-ui/react';
 
-import { MdReadMore } from 'react-icons/md';
+import { MdDoubleArrow } from 'react-icons/md';
 
 import { useGridData } from 'src/api';
 import { getMetaValue } from 'src/utils';
-import AutoRefresh from 'src/components/AutoRefresh';
 import useOffsetHeight from 'src/utils/useOffsetHeight';
 
 import renderTaskRows from './renderTaskRows';
-import ResetRoot from './ResetRoot';
 import DagRuns from './dagRuns';
-import ToggleGroups from './ToggleGroups';
 
 const dagId = getMetaValue('dag_id');
 
@@ -56,6 +52,7 @@ const Grid = ({
 }: Props) => {
   const scrollRef = useRef<HTMLDivElement>(null);
   const tableRef = useRef<HTMLTableSectionElement>(null);
+  const gridRef = useRef<HTMLDivElement>(null);
   const offsetHeight = useOffsetHeight(scrollRef, undefined, 750);
 
   const { data: { groups, dagRuns } } = useGridData();
@@ -96,36 +93,29 @@ const Grid = ({
 
   return (
     <Box
-      m={3}
+      p={3}
+      pt={0}
       mt={0}
       height="100%"
+      ref={gridRef}
+      position="relative"
     >
-      <Flex
-        alignItems="center"
-        justifyContent="space-between"
-        p={1}
-        pb={2}
-        backgroundColor="white"
-      >
-        <Flex alignItems="center">
-          <AutoRefresh />
-          <ToggleGroups
-            groups={groups}
-            openGroupIds={openGroupIds}
-            onToggleGroups={onToggleGroups}
-          />
-          <ResetRoot />
-        </Flex>
-        <IconButton
-          fontSize="2xl"
-          onClick={onPanelToggle}
-          title={`${isPanelOpen ? 'Hide ' : 'Show '} Details Panel`}
-          aria-label={isPanelOpen ? 'Show Details' : 'Hide Details'}
-          icon={<MdReadMore />}
-          transform={!isPanelOpen ? 'rotateZ(180deg)' : undefined}
-          transitionProperty="none"
-        />
-      </Flex>
+      <IconButton
+        fontSize="2xl"
+        variant="ghost"
+        color="gray.400"
+        size="sm"
+        onClick={onPanelToggle}
+        title={`${isPanelOpen ? 'Hide ' : 'Show '} Details Panel`}
+        aria-label={isPanelOpen ? 'Show Details' : 'Hide Details'}
+        icon={<MdDoubleArrow />}
+        transform={!isPanelOpen ? 'rotateZ(180deg)' : undefined}
+        transitionProperty="none"
+        position="absolute"
+        right={0}
+        zIndex={2}
+        top="30px"
+      />
       <Box
         height="100%"
         maxHeight={offsetHeight}
@@ -137,7 +127,11 @@ const Grid = ({
       >
         <Table pr="10px">
           <Thead>
-            <DagRuns />
+            <DagRuns
+              groups={groups}
+              openGroupIds={openGroupIds}
+              onToggleGroups={onToggleGroups}
+            />
           </Thead>
           <Tbody ref={tableRef}>
             {renderTaskRows({
