@@ -20,6 +20,7 @@
 /* global document, window, $, d3, STATE_COLOR, isoDateToTimeEl, autoRefreshInterval,
  localStorage */
 
+import { throttle } from 'lodash';
 import { getMetaValue } from './utils';
 import tiTooltip from './task_instances';
 import { approxTimeFromNow, formatDateTime } from './datetime_utils';
@@ -39,6 +40,8 @@ const lastDagRunsUrl = getMetaValue('last_dag_runs_url');
 const dagStatsUrl = getMetaValue('dag_stats_url');
 const taskStatsUrl = getMetaValue('task_stats_url');
 const gridUrl = getMetaValue('grid_url');
+const datasetsUrl = getMetaValue('datasets_url');
+const nextRunDatasetsSummaryUrl = getMetaValue('next_run_datasets_summary_url');
 
 const nextDatasets = {};
 let nextDatasetsError;
@@ -58,9 +61,10 @@ $('#tags_filter').select2({
 $('#tags_filter').on('change', (e) => {
   e.preventDefault();
   const query = new URLSearchParams(window.location.search);
-  if (e.val.length) {
+  const tags = $(e.target).select2('val');
+  if (tags.length) {
     if (query.has('tags')) query.delete('tags');
-    e.val.forEach((value) => {
+    tags.forEach((value) => {
       query.append('tags', value);
     });
   } else {
@@ -270,6 +274,25 @@ function dagStatsHandler(selector, json) {
   });
 }
 
+function nextRunDatasetsSummaryHandler(_, json) {
+  [...document.getElementsByClassName('next-dataset-triggered')].forEach((el) => {
+    const dagId = $(el).attr('data-dag-id');
+    const previousSummary = $(el).attr('data-summary');
+    const nextDatasetsInfo = json[dagId];
+
+    // Only update dags that depend on multiple datasets
+    if (nextDatasetsInfo && !nextDatasetsInfo.uri) {
+      const newSummary = `${nextDatasetsInfo.ready} of ${nextDatasetsInfo.total} datasets updated`;
+
+      // Only update the element if the summary has changed
+      if (previousSummary !== newSummary) {
+        $(el).attr('data-summary', newSummary);
+        $(el).text(newSummary);
+      }
+    }
+  });
+}
+
 function getDagIds({ activeDagsOnly = false } = {}) {
   let dagIds = $('[id^=toggle]');
   if (activeDagsOnly) {
@@ -386,6 +409,9 @@ function handleRefresh({ activeDagsOnly = false } = {}) {
     d3.json(taskStatsUrl)
       .header('X-CSRFToken', csrfToken)
       .post(params, (error, json) => refreshDagStatsHandler(TASK_INSTANCE, json));
+    d3.json(nextRunDatasetsSummaryUrl)
+      .header('X-CSRFToken', csrfToken)
+      .post(params, nextRunDatasetsSummaryHandler);
   }
   setTimeout(() => {
     $('#loading-dots').css('display', 'none');
@@ -468,17 +494,35 @@ $('#auto_refresh').change(() => {
 $('.next-dataset-triggered').on('click', (e) => {
   const dagId = $(e.target).data('dag-id');
   const summary = $(e.target).data('summary');
-  if (dagId) openDatasetModal(dagId, summary, nextDatasets[dagId], nextDatasetsError);
+  const singleDatasetUri = $(e.target).data('uri');
+
+  // If there are multiple datasets, open a modal, otherwise link directly to the dataset
+  if (!singleDatasetUri) {
+    if (dagId) openDatasetModal(dagId, summary, nextDatasets[dagId], nextDatasetsError);
+  } else {
+    window.location.href = `${datasetsUrl}?uri=${encodeURIComponent(singleDatasetUri)}`;
+  }
 });
 
+const getTooltipInfo = throttle(
+  (dagId, run, setNextDatasets) => getDatasetTooltipInfo(dagId, run, setNextDatasets),
+  1000,
+);
+
 $('.js-dataset-triggered').each((i, cell) => {
   $(cell).on('mouseover', () => {
     const run = $(cell).children();
     const dagId = $(run).data('dag-id');
+    const singleDatasetUri = $(run).data('uri');
+
     const setNextDatasets = (datasets, error) => {
       nextDatasets[dagId] = datasets;
       nextDatasetsError = error;
     };
-    getDatasetTooltipInfo(dagId, run, setNextDatasets);
+
+    // Only update the tooltip info if there are multiple datasets
+    if (!singleDatasetUri) {
+      getTooltipInfo(dagId, run, setNextDatasets);
+    }
   });
 });
