@@ -21,13 +21,13 @@
 
 /*
   global d3, document, nodes, taskInstances, tasks, edges, dagreD3, localStorage, $,
-  autoRefreshInterval, moment, convertSecsToHumanReadable
+  autoRefreshInterval, moment, convertSecsToHumanReadable, priority
 */
 
 import { getMetaValue, finalStatesMap } from './utils';
 import { escapeHtml } from './main';
 import tiTooltip, { taskNoInstanceTooltip } from './task_instances';
-import { callModal } from './dag';
+import callModal from './callModal';
 
 // dagId comes from dag.html
 const dagId = getMetaValue('dag_id');
@@ -43,10 +43,8 @@ const mapTaskToNode = new Map();
 
 // Below variables are being used in dag.js
 
-const getTaskInstanceURL = `${taskInstancesUrl}?dag_id=${encodeURIComponent(dagId)}&execution_date=${
-  encodeURIComponent(executionDate)}`;
+const getTaskInstanceURL = `${taskInstancesUrl}?dag_id=${encodeURIComponent(dagId)}&execution_date=${encodeURIComponent(executionDate)}`;
 
-const duration = 500;
 const stateFocusMap = {
   success: false,
   running: false,
@@ -88,14 +86,24 @@ let innerSvg = d3.select('#graph-svg g');
 const updateNodeLabels = (node, instances) => {
   let haveLabelsChanged = false;
   let { label } = node.value;
-  // Check if there is a count of mapped instances
-  if (tasks[node.id] && tasks[node.id].is_mapped) {
-    const count = instances[node.id]
-      && instances[node.id].mapped_states
-      ? instances[node.id].mapped_states.length
-      : ' ';
 
-    label = `${node.id} [${count}]`;
+  const isGroupMapped = node.value.isMapped;
+  const isTaskMapped = tasks[node.id] && tasks[node.id].is_mapped;
+
+  if (isTaskMapped || isGroupMapped) {
+    // get count from mapped_states or the first child's mapped_states
+    const id = isGroupMapped ? node.children[0].id : node.id;
+    const instance = instances[id];
+    let count = ' ';
+
+    // TODO: update this count for when we can nest mapped tasks inside of mapped task groups
+    if (instance && instance.mapped_states) {
+      count = instance.mapped_states.length;
+    }
+
+    if (!label.includes(`[${count}]`)) {
+      label = `${label} [${count}]`;
+    }
   }
   if (g.node(node.id) && g.node(node.id).label !== label) {
     g.node(node.id).label = label;
@@ -183,8 +191,7 @@ function draw() {
       // A task node
       const task = tasks[nodeId];
       const tryNumber = taskInstances[nodeId].try_number || 0;
-      let mappedStates = [];
-      if (task.is_mapped) mappedStates = taskInstances[nodeId].mapped_states;
+      const mappedStates = taskInstances[nodeId].mapped_states || [];
 
       callModal({
         taskId: nodeId,
@@ -194,7 +201,7 @@ function draw() {
         isSubDag: task.task_type === 'SubDagOperator',
         dagRunId,
         mapIndex: task.map_index,
-        isMapped: task.is_mapped,
+        isMapped: task.is_mapped || !!taskInstances[nodeId].mapped_states,
         mappedStates,
       });
     }
@@ -234,6 +241,7 @@ function draw() {
 }
 
 let zoom = null;
+const maxZoom = 0.3;
 
 function setUpZoomSupport() {
   // Set up zoom support for Graph
@@ -246,21 +254,17 @@ function setUpZoomSupport() {
   // Get Dagre Graph dimensions
   const graphWidth = g.graph().width;
   const graphHeight = g.graph().height;
-  // Get SVG dimensions
-  const padding = 80;
-  const svgBb = svg.node().getBoundingClientRect();
-  const width = svgBb.width - padding * 2;
-  const height = svgBb.height - padding; // we are not centering the dag vertically
+  const { width, height } = svg.node().viewBox.animVal;
+  const padding = width * 0.05;
 
   // Calculate applicable scale for zoom
-  const zoomScale = Math.min(
-    Math.min(width / graphWidth, height / graphHeight),
-    1.5, // cap zoom level to 1.5 so nodes are not too large
-  );
+
+  const zoomScale = Math.min(Math.min(width / graphWidth, height / graphHeight), maxZoom) * 0.8;
 
   zoom.translate([(width / 2) - ((graphWidth * zoomScale) / 2) + padding, padding]);
   zoom.scale(zoomScale);
   zoom.event(innerSvg);
+  zoom.scaleExtent([0, maxZoom]);
 }
 
 function highlightNodes(nodes) {
@@ -353,20 +357,7 @@ d3.select('#searchbox').on('keyup', () => {
 
   // This moves the matched node to the center of the graph area
   if (match) {
-    const transform = d3.transform(d3.select(match).attr('transform'));
-
-    const svgBb = svg.node().getBoundingClientRect();
-    transform.translate = [
-      svgBb.width / 2 - transform.translate[0],
-      svgBb.height / 2 - transform.translate[1],
-    ];
-    transform.scale = [1, 1];
-
-    if (zoom != null) {
-      zoom.translate(transform.translate);
-      zoom.scale(1);
-      zoom.event(innerSvg);
-    }
+    focusGroup(match.id, false);
   }
 });
 
@@ -432,12 +423,11 @@ function handleRefresh() {
       (tis) => {
         // only refresh if the data has changed
         if (prevTis !== tis) {
-        // eslint-disable-next-line no-global-assign
-          taskInstances = JSON.parse(tis);
-          updateNodesStates(taskInstances);
+          // eslint-disable-next-line no-global-assign
+          updateNodesStates(tis);
 
           // Only redraw the graph if labels have changed
-          const haveLabelsChanged = updateNodeLabels(nodes, taskInstances);
+          const haveLabelsChanged = updateNodeLabels(nodes, tis);
           if (haveLabelsChanged) draw();
 
           // end refresh if all states are final
@@ -487,19 +477,29 @@ function groupTooltip(node, tis) {
   let minStart;
   let maxEnd;
 
-  getChildrenIds(node).forEach((child) => {
-    if (child in tis) {
-      const ti = tis[child];
-      if (!minStart || moment(ti.start_date).isBefore(minStart)) {
-        minStart = moment(ti.start_date);
+  if (node.isMapped) {
+    const firstChildId = node.children[0].id;
+    const mappedLength = tis[firstChildId].mapped_states.length;
+    [...Array(mappedLength).keys()].forEach((mapIndex) => {
+      const groupStates = getChildrenIds(node).map((child) => tis[child].mapped_states[mapIndex]);
+      const overallState = priority.find((state) => groupStates.includes(state)) || 'no_status';
+      if (numMap.has(overallState)) numMap.set(overallState, numMap.get(overallState) + 1);
+    });
+  } else {
+    getChildrenIds(node).forEach((child) => {
+      if (child in tis) {
+        const ti = tis[child];
+        if (!minStart || moment(ti.start_date).isBefore(minStart)) {
+          minStart = moment(ti.start_date);
+        }
+        if (!maxEnd || moment(ti.end_date).isAfter(maxEnd)) {
+          maxEnd = moment(ti.end_date);
+        }
+        const stateKey = ti.state == null ? 'no_status' : ti.state;
+        if (numMap.has(stateKey)) numMap.set(stateKey, numMap.get(stateKey) + 1);
       }
-      if (!maxEnd || moment(ti.end_date).isAfter(maxEnd)) {
-        maxEnd = moment(ti.end_date);
-      }
-      const stateKey = ti.state == null ? 'no_status' : ti.state;
-      if (numMap.has(stateKey)) numMap.set(stateKey, numMap.get(stateKey) + 1);
-    }
-  });
+    });
+  }
 
   const groupDuration = convertSecsToHumanReadable(moment(maxEnd).diff(minStart, 'second'));
   const tooltipText = node.tooltip ? `<p>${node.tooltip}</p>` : '';
@@ -533,7 +533,7 @@ function updateNodesStates(tis) {
       elem.onmouseover = (evt) => {
         let tt;
         if (taskId in tis) {
-          tt = tiTooltip(tis[taskId]);
+          tt = tiTooltip(tis[taskId], tasks[taskId]);
         } else if (node.children) {
           tt = groupTooltip(node, tis);
         } else if (taskId in tasks) {
@@ -599,12 +599,6 @@ function getNodeState(nodeId, tis) {
     }
   });
 
-  // In this order, if any of these states appeared in childrenStates, return it as
-  // the group state.
-  const priority = ['failed', 'upstream_failed', 'up_for_retry', 'up_for_reschedule',
-    'queued', 'scheduled', 'sensing', 'running', 'shutdown', 'restarting', 'removed',
-    'no_status', 'success', 'skipped'];
-
   return priority.find((state) => childrenStates.has(state)) || 'no_status';
 }
 
@@ -619,32 +613,36 @@ function focusedGroupKey() {
 }
 
 // Focus the graph on the expanded/collapsed node
-function focusGroup(nodeId) {
+function focusGroup(nodeId, followMouse = true) {
   if (nodeId != null && zoom != null) {
-    const { x } = g.node(nodeId);
+    const { x, y } = g.node(nodeId);
     // This is the total canvas size.
-    const { width, height } = svg.node().getBoundingClientRect();
+    const { width, height } = svg.node().viewBox.animVal;
 
     // This is the size of the node or the cluster (i.e. group)
     let rect = d3.selectAll('g.node').filter((n) => n === nodeId).select('rect');
     if (rect.empty()) rect = d3.selectAll('g.cluster').filter((n) => n === nodeId).select('rect');
 
+    const [mouseX, mouseY] = d3.mouse(svg.node());
+
     // Is there a better way to get nodeWidth and nodeHeight ?
     const [nodeWidth, nodeHeight] = [
       rect[0][0].attributes.width.value, rect[0][0].attributes.height.value,
     ];
 
     // Calculate zoom scale to fill most of the canvas with the node/cluster in focus.
-    const scale = Math.min(
-      Math.min(width / nodeWidth, height / nodeHeight),
-      1.5, // cap zoom level to 1.5 so nodes are not too large
-    ) * 0.9;
+    const scale = Math.min(Math.min(width / nodeWidth, height / nodeHeight), maxZoom) * 0.4;
 
-    // deltaY of 5 keeps the zoom at the top of the view but with a slight margin
-    const [deltaX, deltaY] = [width / 2 - x * scale, 5];
+    // Move the graph so that the node that was expanded/collapsed is centered around
+    // the mouse click.
+    const [toX, toY] = followMouse ? [mouseX, mouseY] : [width / 2, height / 5];
+    const [deltaX, deltaY] = [
+      toX - x * scale,
+      toY + (nodeHeight / 2 - y) * scale,
+    ];
     zoom.translate([deltaX, deltaY]);
     zoom.scale(scale);
-    zoom.event(innerSvg.transition().duration(duration));
+    zoom.event(innerSvg);
 
     const children = new Set(g.children(nodeId));
     // Set data attr to highlight the focused group (via CSS).
